﻿using System;
using System.Collections.Generic;
using WPF.Client.PurolatorWebServiceReference;

namespace WPF.Client
{
	public static class ObjectHelper
	{
		public static OrderRequestV3 GetRandomOrderRequest(CredentialInfo credentials)
		{
			// Since this order does not have Saturday service selected, only Monday thru Friday are valid.
			DateTime estShipDate = DateTime.Today;
			while (estShipDate.DayOfWeek == DayOfWeek.Saturday || estShipDate.DayOfWeek == DayOfWeek.Sunday)
				estShipDate = estShipDate.AddDays(1);

			OrderRequestV3 request = new OrderRequestV3
			{
				Credentials = credentials,
				ShipFromAddress = new Address
				{
					Company    = "My Company",
					Add1       = "290 Spagnoli Road",
					City       = "Melville",
					StateProv  = "NY",
					PostalCode = "11747",
					Country    = "US",
				},
				ShipToAddress = new Address
				{
					Name       = "Test Customer Name",
					Add1       = "560 Kings Road",
					City       = "Sydney",
					StateProv  = "NS",
					PostalCode = "B1S1B8",
					Country    = "CA"
				},

				// The OrderNumber must be unique for non-voided orders for an Account.
				OrderNumber = "RndOrder-" + Guid.NewGuid().ToString().Replace("-", "").Substring(0, 10),
				// Ground shipping is available for most postal codes, but only Air is available for some postal codes.
				ShipMethod = "GROUND",

				// LabelType indicates how we want to handle printing labels.
				// NONE: Do not mark the package label as printed; get labels later using a GetLabel request.
				// ZPL: Include the non-image ZPL code for printing the label - requires sending the response from a prior
				//	GetZPLInitializationImages request for the Purolator icons to be printed.
				// ZPLIMAGES: Include both the ZPL code for the Purolator icons and for the rest of the label.
				// IMAGE: Return the label as a PNG image encoded as a Base64 string.

				// Using the ZPL option is recommended since it substantially reduces the response size compared to ZPLIMAGES or IMAGE.
				// ZPLIMAGES is used in this demo code for simplicity.
				LabelType = "ZPLIMAGES",
				ShipDate = estShipDate,
				Packages = new List<RequestPackageV3>
				{
					new RequestPackageV3
					{
						PackageID = "PKG-" + Guid.NewGuid().ToString().Replace("-", "").Substring(0, 6),
						WeightUOM = "LB",
						Weight = 10.0m,
					}
				}.ToArray(),
				// Items are required if Purolator is handling customs; otherwise item information is ignored.
				Items = new List<RequestItemV3>
				{
					new RequestItemV3
					{
						SKU         = "x35135",
						CustomsDesc = "Documents",
						Quantity    = 2,
						TotalValue  = 10,
						Currency    = "CAD",
						CountryOfOrigin = "United States",
					}
				}.ToArray()
			};

			return request;
		}

		public static CloseoutRequest GetCloseoutRequest(CredentialInfo credentials, string[] packageIDs)
		{
			CloseoutRequest request = new CloseoutRequest
			{
				Credentials = credentials,
				// Indicate the packages we want to close out based on the PackageID field.
				// We could instead provide Pins/Tracking numbers and set PackIDType to Pin
				PackageIDs = packageIDs,
				PackIDType = "PackageID",
				SkidCount = 1,
				ParsNumber = Guid.NewGuid().ToString().Substring(0, 12)
			};

			return request;
		}
	}
}
